@@ -47,7 +47,7 @@ class OctavePlotExtension : public Cantor::PlotExtension
     public:
     OCTAVE_EXT_CDTOR_DECL(Plot)
     QString plotFunction2d(const QString& function, const QString& variable, const QString& left, const QString& right) Q_DECL_OVERRIDE;
-    QString plotFunction3d(const QString& function, VariableParameter var1, VariableParameter var2) Q_DECL_OVERRIDE;
+    QString plotFunction3d(const QString& function, const VariableParameter& var1, const VariableParameter& var2) Q_DECL_OVERRIDE;
 };
 
 class OctaveLinearAlgebraExtension : public Cantor::LinearAlgebraExtension
