@@ -31,19 +31,14 @@
 #include <QMimeDatabase>
 #include <QRegExp>
 
-SageExpression::SageExpression( Cantor::Session* session ) : Cantor::Expression(session)
+SageExpression::SageExpression( Cantor::Session* session ) : Cantor::Expression(session),
+    m_isHelpRequest(false),
+    m_promptCount(0)
 {
-    qDebug();
-}
-
-SageExpression::~SageExpression()
-{
-
 }
 
 void SageExpression::evaluate()
 {
-    qDebug()<<"evaluating "<<command();
     setStatus(Cantor::Expression::Computing);
     m_imagePath.clear();
 
@@ -177,7 +172,7 @@ void SageExpression::evalFinished()
 
     if ( !hasImage ) //If this result contains a file, drop the text information
     {
-        Cantor::TextResult* result=0;
+        Cantor::TextResult* result=nullptr;
 
         QString stripped=m_outputCache;
         const bool isHtml=stripped.contains(QLatin1String("<html>"));
@@ -266,4 +261,3 @@ QString SageExpression::additionalLatexHeaders()
                          "\\newcommand{\\CFF}{\\Bold{CFF}}\n");
 }
 
-#include "sageexpression.moc"
